Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
audoma_api/exceptions.py | 8 | 0 | 0 | 100%
audoma_api/fields.py | 5 | 0 | 0 | 100%
audoma_api/models.py | 62 | 60 | 0 | 3%
audoma_api/permissions.py | 18 | 6 | 0 | 67%
audoma_api/serializers.py | 96 | 0 | 0 | 100%
audoma_api/views.py | 99 | 6 | 0 | 94%
audoma/choices.py | 16 | 5 | 0 | 69%
audoma/decorators.py | 152 | 10 | 0 | 93%
audoma/django/db/fields.py | 71 | 45 | 0 | 37%
audoma/django/db/models.py | 2 | 2 | 0 | 0%
audoma/django/forms/fields.py | 0 | 0 | 5 | 100%
audoma/drf/decorators.py | 15 | 0 | 0 | 100%
audoma/drf/fields.py | 65 | 47 | 1 | 28%
audoma/drf/filters.py | 10 | 0 | 0 | 100%
audoma/drf/generics.py | 30 | 8 | 0 | 73%
audoma/drf/mixins.py | 107 | 40 | 0 | 63%
audoma/drf/routers.py | 5 | 0 | 0 | 100%
audoma/drf/serializers.py | 112 | 43 | 15 | 62%
audoma/drf/validators.py | 19 | 0 | 0 | 100%
audoma/drf/viewsets.py | 22 | 13 | 0 | 41%
audoma/example_generators.py | 11 | 4 | 0 | 64%
audoma/examples.py | 32 | 16 | 0 | 50%
audoma/hooks.py | 29 | 2 | 0 | 93%
audoma/links.py | 80 | 14 | 0 | 82%
audoma/mixins.py | 25 | 11 | 0 | 56%
audoma/openapi.py | 237 | 26 | 0 | 89%
audoma/operations.py | 64 | 12 | 0 | 81%
audoma/plumbing.py | 14 | 7 | 0 | 50%
audoma/schema.py | 69 | 24 | 0 | 65%
Total | 1475 | 401 | 21 | 73%

No items found using the specified filter.